==> binnie-mods-1.11.2-2.1.0.36-sources.jar: binnie/core/machines/inventory/IInventoryMachine.java <==
package binnie.core.machines.inventory;

import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.IInventory;
import net.minecraft.inventory.ISidedInventory;
import net.minecraft.item.ItemStack;

public interface IInventoryMachine extends IInventory, ISidedInventory, IValidatedInventory {
	IInventory getInventory();

	@Override
	default int func_70302_i_() {
		return this.getInventory().func_70302_i_();
	}

	@Override
	default ItemStack func_70301_a(final int index) {
		return this.getInventory().func_70301_a(index);
	}

	@Override
	default ItemStack func_70298_a(final int index, final int amount) {
		return this.getInventory().func_70298_a(index, amount);
	}

	@Override
	default ItemStack func_70304_b(int index) {
		return this.getInventory().func_70304_b(index);
	}

	@Override
	default void func_70299_a(final int index, final ItemStack itemStack) {
		this.getInventory().func_70299_a(index, itemStack);
	}

	@Override
	default boolean func_191420_l() {
		return this.getInventory().func_191420_l();
	}

	@Override
	default String func_70005_c_() {
		return this.getInventory().func_70005_c_();
	}

	@Override
	default int func_70297_j_() {
		return this.getInventory().func_70297_j_();
	}

	@Override
	default void func_174889_b(EntityPlayer player) {
		this.getInventory().func_174889_b(player);
	}

	@Override
	default void func_174886_c(EntityPlayer player) {
		this.getInventory().func_174886_c(player);
	}

	@Override
	default boolean func_145818_k_() {
		return this.getInventory().func_145818_k_();
	}

	@Override
	default boolean func_94041_b(final int slot, final ItemStack itemStack) {
		return this.getInventory().func_94041_b(slot, itemStack);
	}

	@Override
	default int func_174887_a_(int id) {
		return this.getInventory().func_174887_a_(id);
	}

	@Override
	default void func_174885_b(int id, int value) {
		this.getInventory().func_174885_b(id, value);
	}

	@Override
	default int func_174890_g() {
		return this.getInventory().func_174890_g();
	}

	@Override
	default void func_174888_l() {
		this.getInventory().func_174888_l();
	}
}

==> binnie-mods-1.12-2.2.0.7-sources.jar: binnie/core/machines/inventory/IInventoryMachine.java <==
package binnie.core.machines.inventory;

import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.IInventory;
import net.minecraft.inventory.ISidedInventory;
import net.minecraft.item.ItemStack;

public interface IInventoryMachine extends IInventory, ISidedInventory {
	IInventory getInventory();

	@Override
	default int func_70302_i_() {
		return this.getInventory().func_70302_i_();
	}

	@Override
	default ItemStack func_70301_a(final int index) {
		return this.getInventory().func_70301_a(index);
	}

	@Override
	default ItemStack func_70298_a(final int index, final int amount) {
		return this.getInventory().func_70298_a(index, amount);
	}

	@Override
	default ItemStack func_70304_b(int index) {
		return this.getInventory().func_70304_b(index);
	}

	@Override
	default void func_70299_a(final int index, final ItemStack itemStack) {
		this.getInventory().func_70299_a(index, itemStack);
	}

	@Override
	default boolean func_191420_l() {
		return this.getInventory().func_191420_l();
	}

	@Override
	default String func_70005_c_() {
		return this.getInventory().func_70005_c_();
	}

	@Override
	default int func_70297_j_() {
		return this.getInventory().func_70297_j_();
	}

	@Override
	default void func_174889_b(EntityPlayer player) {
		this.getInventory().func_174889_b(player);
	}

	@Override
	default void func_174886_c(EntityPlayer player) {
		this.getInventory().func_174886_c(player);
	}

	@Override
	default boolean func_145818_k_() {
		return this.getInventory().func_145818_k_();
	}

	@Override
	default boolean func_94041_b(final int slot, final ItemStack itemStack) {
		return this.getInventory().func_94041_b(slot, itemStack);
	}

	@Override
	default int func_174887_a_(int id) {
		return this.getInventory().func_174887_a_(id);
	}

	@Override
	default void func_174885_b(int id, int value) {
		this.getInventory().func_174885_b(id, value);
	}

	@Override
	default int func_174890_g() {
		return this.getInventory().func_174890_g();
	}

	@Override
	default void func_174888_l() {
		this.getInventory().func_174888_l();
	}
}
